# frozen_string_literal: true

require 'vips'

module Jekyll
  module Images
    class Image
      attr_reader :site, :filename

      def initialize(site, filename)
        unless File.exist? filename
          raise ArgumentError, "File not found: #{filename}"
        end

        @cached_thumbnails = {}
        @site = site
        @filename = filename
      end

      def image
        @image ||= Vips::Image.new_from_file filename, access: :sequential
      end

      def thumbnail(**args)
        @cached_thumbnails[args.hash.to_s] ||= Thumbnail.new site: site, filename: filename, image: image, **args
      end
    end
  end
end
